Interface: ArcBorderRadius | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ArcBorderRadius

## # Properties

### # innerEnd

• innerEnd: `number`

#### # Defined in

index.esm.d.ts:1725
(opens new window)

### # innerStart

• innerStart: `number`

#### # Defined in

index.esm.d.ts:1724
(opens new window)

### # outerEnd

• outerEnd: `number`

#### # Defined in

index.esm.d.ts:1723
(opens new window)

### # outerStart

• outerStart: `number`

#### # Defined in

index.esm.d.ts:1722
(opens new window)